@@ -8,7 +8,7 @@ package Devel::MAT::Dumpfile;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Carp;
 use IO::Handle;   # ->read
@@ -40,35 +40,56 @@ SV is represented by an instance of L<Devel::MAT::SV>.
 my @ROOTS;
 my %ROOTDESC;
 foreach (
-   [ maincv        => "the main code" ],
-   [ defstash      => "the default stash" ],
-   [ mainstack     => "the main stack AV" ],
-   [ beginav       => "the BEGIN list" ],
-   [ checkav       => "the CHECK list" ],
-   [ unitcheckav   => "the UNITCHECK list" ],
-   [ initav        => "the INIT list" ],
-   [ endav         => "the END list" ],
-   [ strtabhv      => "the shared string table HV" ],
-   [ envgv         => "the ENV GV" ],
-   [ incgv         => "the INC GV" ],
-   [ statgv        => "the stat GV" ],
-   [ statname      => "the statname SV" ],
-   [ tmpsv         => "the temporary SV" ],
-   [ defgv         => "the default GV" ],
-   [ argvgv        => "the ARGV GV" ],
-   [ argvoutgv     => "the argvout GV" ],
-   [ argvout_stack => "the argvout stack AV" ],
-   [ fdpidav       => "the FD-to-PID mapping AV" ],
-   [ preambleav    => "the compiler preamble AV" ],
-   [ modglobalhv   => "the module data globals HV" ],
-   [ regex_padav   => "the REGEXP pad AV" ],
-   [ sortstash     => "the sort stash" ],
-   [ firstgv       => "the *a GV" ],
-   [ secondgv      => "the *b GV" ],
-   [ debstash      => "the debugger stash" ],
-   [ stashcache    => "the stash cache" ],
-   [ isarev        => "the reverse map of \@ISA dependencies" ],
-   [ mros          => "the registered MROs HV" ],
+   [ main_cv         => "the main code" ],
+   [ defstash        => "the default stash" ],
+   [ mainstack       => "the main stack AV" ],
+   [ beginav         => "the BEGIN list" ],
+   [ checkav         => "the CHECK list" ],
+   [ unitcheckav     => "the UNITCHECK list" ],
+   [ initav          => "the INIT list" ],
+   [ endav           => "the END list" ],
+   [ strtabhv        => "the shared string table HV" ],
+   [ envgv           => "the ENV GV" ],
+   [ incgv           => "the INC GV" ],
+   [ statgv          => "the stat GV" ],
+   [ statname        => "the statname SV" ],
+   [ tmpsv           => "the temporary SV" ],
+   [ defgv           => "the default GV" ],
+   [ argvgv          => "the ARGV GV" ],
+   [ argvoutgv       => "the argvout GV" ],
+   [ argvout_stack   => "the argvout stack AV" ],
+   [ fdpidav         => "the FD-to-PID mapping AV" ],
+   [ preambleav      => "the compiler preamble AV" ],
+   [ modglobalhv     => "the module data globals HV" ],
+   [ regex_padav     => "the REGEXP pad AV" ],
+   [ sortstash       => "the sort stash" ],
+   [ firstgv         => "the *a GV" ],
+   [ secondgv        => "the *b GV" ],
+   [ debstash        => "the debugger stash" ],
+   [ stashcache      => "the stash cache" ],
+   [ isarev          => "the reverse map of \@ISA dependencies" ],
+   [ registered_mros => "the registered MROs HV" ],
+   [ rs              => "the IRS" ],
+   [ last_in_gv      => "the last input GV" ],
+   [ ofsgv           => "the OFS GV" ],
+   [ defoutgv        => "the default output GV" ],
+   [ hintgv          => "the hints (%^H) GV" ],
+   [ patchlevel      => "the patch level" ],
+   [ apiversion      => "the API version" ],
+   [ e_script        => "the '-e' script" ],
+   [ mess_sv         => "the message SV" ],
+   [ ors_sv          => "the ORS SV" ],
+   [ encoding        => "the encoding" ],
+   [ blockhooks      => "the block hooks" ],
+   [ custom_ops      => "the custom ops HV" ],
+   [ custom_op_names => "the custom op names HV" ],
+   [ custom_op_descs => "the custom op descriptions HV" ],
+   map { [ $_ => "the $_" ] } qw(
+      Latin1 UpperLatin1 AboveLatin1 NonL1NonFinalFold HasMultiCharFold
+      utf8_mark utf8_X_regular_begin utf8_X_extend utf8_toupper utf8_totitle
+      utf8_tolower utf8_tofold utf8_charname_begin utf8_charname_continue
+      utf8_idstart utf8_idcont utf8_xidstart utf8_perl_idstart utf8_perl_idcont
+      utf8_xidcont utf8_foldclosures utf8_foldable ),
 ) {
    my ( $name, $desc ) = @$_;
    push @ROOTS, $name;
@@ -156,8 +177,10 @@ sub load
       my $class = "Devel::MAT::SV::\U$_";
       $self->{uc $_} = $class->_new( $self, $addr );
    }
-   foreach (@ROOTS) {
-      $self->{"${_}_at"} = $self->_read_ptr;
+
+   foreach ( 1 .. $self->_read_u32 ) {
+      my $root = $self->_read_str;
+      $self->{"${root}_at"} = $self->_read_ptr;
    }
 
    # Stack
@@ -392,7 +415,7 @@ sub roots
 For each of the root names given below, a method exists with that name which
 returns the SV at that root:
 
- maincv
+ main_cv
  defstash
  mainstack
  beginav
@@ -420,7 +443,7 @@ returns the SV at that root:
  debstash
  stashcache
  isarev
- mros
+ registered_mros
 
 =cut
 
